@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report get_files );
 
-$VERSION = '0.53.1'; # our $VERSION = '';
+$VERSION = '0.53.3'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -1189,6 +1189,15 @@ sub report # This function retrieves the results of interest from the texts file
       {
         $thing =~ s/\n/ /g ; $thing =~ s/\n/ /g ; $thing =~ s/\r/ /g ; $thing =~ s/\r/ /g ;
         $thing =~ s/\r\n/ /g; $thing =~ s/\r\n/ /g;
+        $thing =~ s/  / / ;
+        $thing =~ s/  / / ;
+        $thing =~ s/  / / ;
+        $thing =~ s/  / / ;
+        $thing =~ s/  / / ;
+        $thing =~ s/  / / ;
+        $thing =~ s/ ,/,/ ;
+        $thing =~ s/, /,/ ;
+        $thing =~ s/ /,/ ;
         print REPFILE $thing;
         print REPFILE ",";
       }
@@ -1214,21 +1223,35 @@ sub report # This function retrieves the results of interest from the texts file
   
   #foreach ( sort ( @{ $convey[ $countcase ][ $counblock ] } ) )
   #{
-    $_ =~ s/  / / ;
-    $_ =~ s/  / / ;
-    $_ =~ s/  / / ;
-    $_ =~ s/  / / ;
-    $_ =~ s/  / / ;
-    $_ =~ s/ /,/ ;
+    
 
     print REPFILE "$_\n"; 
   #}
   close REPFILE;
 
   my $repstore = $repfile . ".csv";
-  `cp -f $repfile $repstore`;
-  print REPORT "cp -f $repfile $repstore\n";
-    
+  
+  open ( REPFILE, "$repfile" ) or die "$!";
+  my @lins = <REPFILE>;
+  close  REPFILE;
+
+  open( REPSTORE, ">$repstore" ) or die "$!";
+  foreach my $lin ( @lins )
+  {
+  	$lin =~ s/  / / ;
+    $lin =~ s/  / / ;
+    $lin =~ s/  / / ;
+    $lin =~ s/  / / ;
+    $lin =~ s/  / / ;
+    $lin =~ s/  / / ;
+    $lin =~ s/ ,/,/ ;
+    $lin =~ s/, /,/ ;
+    $lin =~ s/ /,/ ;
+    print REPSTORE "$lin";
+  }
+
+  close REPSTORE;
+
   say $tee "HEREIS \@repcases " . dump(@repcases); say $tee "\@repstruct " . dump(@repstruct); 
   
   close TOFILE;
