@@ -29,8 +29,10 @@ $computype = "linear";
 # WHEN UNSPECIFIED, THE DEFAULT IS "linear".
 
 @calcprocedures = ( "complete", "diluted" );
+#@calcprocedures = ( "complete", "besides", "diluted", "extra" );
 # The options are the following:
-# "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff", "halved".
+# "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff", "diluted", "quadratic__", "sqroot__", "halved__", 
+# "conflated", "conflated__", "extra", "besides", "halved", "halved250", "halved125", "halved375".
 # "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
 # The others can't. "basic" also can be combined with the others: it can be used in place of "alternative".
 # "spreaddiff"c CAN'T BE USED ALONE.
@@ -38,8 +40,13 @@ $computype = "linear";
 # MORE THAN ONE OPTION MAY CO-EXIST.
 # WITH THE "complete", "alternative" and "main" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
 # WHEN NO @calcprocedures VALUE IS PRESENT, THE PROGRAM DEFAULTS TO "simplified".
+# The main alternatives are: "complete", "besides"; and complete besides diluted extra.
+# "besides" means that the specular reflection of the reflectors is also specified in the Radiance database.
+# "extra" means that the specular reflection of all materials is specifies in the database.
+# Both, can be used with $computype = "linear" or "root".
+# 
 
-%specularratios = ( reflector => 0 );
+%specularratios = ( reflector => 0, roughnval => 0.25 );
 #%specularratios = ( totaldirect => 1 );
 #%specularratios = ( reflector => 1 );
 # THE VALUE OF EACH OF THESE KEY-VALUE PAIRS CONSTITUTES THE PROPORTION OF THE SPECULAR REFLECTIVITY
@@ -51,6 +58,9 @@ $computype = "linear";
 # CONSTITUTES THE PROPORTION OF THE TOTAL DIRECT RADIATION IF THE TOTAL DIFFUSE RADIATION IS 1.
 # EXAMPLE: %specularratios = ( totaldirect => 1 );
 # (SEE SUBROUTINE "pursue").
+# IF IN @calcprocedures "besides" is present, in %specularratios a roughness value 
+# between 0 and 1 must be spefied as "roughnval". EXAMPLE:
+# %specularratios = ( roughnval => 0.25 );
 
 %skycondition = ( 1=> "clear", 2=> "clear", 3=> "clear", 4=> "clear", 5=> "clear", 6=> "clear", 7=> "clear", 8=> "clear", 
 	9=> "clear", 10=> "clear", 11=> "clear", 12=> "clear" );
